==> mule-tests-unit-4.11.0-20251017.045202-120-sources.jar: org/mule/tck/ZipUtils.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.tck;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.UncheckedIOException;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * Provides utility methods to work with ZIP files
 */
public class ZipUtils {

  private ZipUtils() {}

  /**
   * Describes a resource that can be compressed in a ZIP file
   */
  public static class ZipResource {

    private final String file;
    private final String alias;

    public ZipResource(String file, String alias) {
      this.file = file;
      this.alias = alias;
    }

    public String getFile() {
      return file;
    }

    public String getAlias() {
      return alias;
    }
  }

  /**
   * Compress a set of resource files into a ZIP file
   *
   * @param targetFile file that will contain the zipped files
   * @param resources  resources to compress
   * @throws UncheckedIOException in case of any error processing the files
   */
  public static void compress(File targetFile, ZipResource[] resources) {
    try (ZipOutputStream out = new ZipOutputStream(new FileOutputStream(targetFile))) {
      for (ZipResource zipResource : resources) {
        try (InputStream in = getResourceOrFileAsStream(zipResource.file)) {
          out.putNextEntry(new ZipEntry(zipResource.alias == null ? zipResource.file : zipResource.alias));

          byte[] buffer = new byte[1024];

          int count;
          while ((count = in.read(buffer)) > 0) {
            out.write(buffer, 0, count);
          }
        }
      }
    } catch (IOException e) {
      throw new UncheckedIOException(e);
    }
  }

  private static InputStream getResourceOrFileAsStream(String resourceOrFileName) throws FileNotFoundException {
    var zipResourceAsStream = ZipUtils.class.getClassLoader().getResourceAsStream(resourceOrFileName);
    if (zipResourceAsStream == null) {
      zipResourceAsStream = new FileInputStream(new File(resourceOrFileName));
    }

    return zipResourceAsStream;
  }
}

==> mule-tests-unit-4.11.0-20251126.153849-178-sources.jar: org/mule/tck/ZipUtils.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.tck;

import static java.nio.file.Files.newInputStream;
import static java.nio.file.Files.newOutputStream;

import java.io.IOException;
import java.io.InputStream;
import java.io.UncheckedIOException;
import java.nio.file.Path;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * Provides utility methods to work with ZIP files
 */
public class ZipUtils {

  private ZipUtils() {}

  /**
   * Describes a resource that can be compressed in a ZIP file
   */
  public static class ZipResource {

    private final String file;
    private final String alias;

    public ZipResource(String file, String alias) {
      this.file = file;
      this.alias = alias;
    }

    public String getFile() {
      return file;
    }

    public String getAlias() {
      return alias;
    }
  }

  /**
   * Compress a set of resource files into a ZIP file
   *
   * @param targetFile file that will contain the zipped files
   * @param resources  resources to compress
   * @throws UncheckedIOException in case of any error processing the files
   */
  public static void compress(Path targetFile, ZipResource[] resources) {
    try (ZipOutputStream out = new ZipOutputStream(newOutputStream(targetFile))) {
      for (ZipResource zipResource : resources) {
        try (InputStream in = getResourceOrFileAsStream(zipResource.file)) {
          out.putNextEntry(new ZipEntry(zipResource.alias == null ? zipResource.file : zipResource.alias));

          byte[] buffer = new byte[1024];

          int count;
          while ((count = in.read(buffer)) > 0) {
            out.write(buffer, 0, count);
          }
        }
      }
    } catch (IOException e) {
      throw new UncheckedIOException(e);
    }
  }

  private static InputStream getResourceOrFileAsStream(String resourceOrFileName) throws IOException {
    var zipResourceAsStream = ZipUtils.class.getClassLoader().getResourceAsStream(resourceOrFileName);
    if (zipResourceAsStream == null) {
      zipResourceAsStream = newInputStream(Path.of(resourceOrFileName));
    }

    return zipResourceAsStream;
  }
}
